pub enum NextControlFlowPosition {
Maintain,
SameLine,
NextLine,
}Expand description
Where to place the next control flow within a control flow statement.
Variants
Maintain
Maintains the next control flow being on the next line or the same line.
SameLine
Forces the next control flow to be on the same line.
NextLine
Forces the next control flow to be on the next line.