pub enum OperatorPosition {
Maintain,
SameLine,
NextLine,
}Expand description
Where to place the operator for expressions that span multiple lines.
Variants
Maintain
Maintains the operator being on the next line or the same line.
SameLine
Forces the operator to be on the same line.
NextLine
Forces the operator to be on the next line.