pub enum SameOrNextLinePosition {
Maintain,
SameLine,
NextLine,
}Expand description
Where to place a node that could be on the same line or next line.
Variants
Maintain
Maintains the position of the expression.
SameLine
Forces the whole statement to be on one line.
NextLine
Forces the expression to be on the next line.